Package: vueR
Type: Package
Title: 'Vuejs' Helpers and 'Htmlwidget'
Version: 0.6.0
Date: 2023-10-01
Authors@R: c(
      person(
        "Evan","You"
        , role = c("aut", "cph")
        , comment = "vue library in lib, https://vuejs.org/; see BACKERS for full list of Patreon backers"
      ),
      person(
        "Kent", "Russell"
        , role = c("aut", "cre")
        , comment = "R interface"
        , email = "kent.russell@timelyportfolio.com"
      )
    )
Maintainer: Kent Russell <kent.russell@timelyportfolio.com>
Description: Make it easy to use 'vue' in R with helper
              dependency functions and examples.
URL: https://github.com/vue-r/vueR
BugReports: https://github.com/vue-r/vueR/issues
License: MIT + file LICENSE
Imports: htmltools, htmlwidgets (>= 0.6.0)
Suggests: knitr, rmarkdown, shiny, testthat
RoxygenNote: 7.2.3
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2023-10-01 16:56:22 UTC; kentr
Author: Evan You [aut, cph] (vue library in lib, https://vuejs.org/; see
    BACKERS for full list of Patreon backers),
  Kent Russell [aut, cre] (R interface)
Repository: CRAN
Date/Publication: 2023-10-01 17:10:02 UTC
Built: R 4.6.0; ; 2026-04-25 12:38:33 UTC; unix
