# Generated by roxygen2: do not edit by hand

export(html_dependency_vue)
export(html_dependency_vue3)
export(renderVue)
export(renderVue3)
export(vue)
export(vue3)
export(vue3Output)
export(vueOutput)
import(htmlwidgets)
importFrom(htmltools,htmlDependency)
